> ## THIS PROJECT IS OPEN FOR MAINTAINERS
> Development on the ptyhon-social-auth projects has been stagnated for a while,
> #445 was open a long time ago to discuss this matter and a plan (failed) was
> presented to fix the situation. For that reason, I'm opening the organization to
> new maintainers that will have the proper permissions to unstuck development.
>
> Those willing to join, contact me by email with the subject `[PSA Maintainer]
> <your name>` and please let me know what motivates you to join in such role.

# Python Social Auth - Core
![Build Status](https://github.com/python-social-auth/social-core/workflows/Flake8/badge.svg)
![Build Status](https://github.com/python-social-auth/social-core/workflows/Tests/badge.svg)
[![Build Status](https://travis-ci.org/python-social-auth/social-core.svg?branch=master)](https://travis-ci.org/python-social-auth/social-core)
[![PyPI version](https://badge.fury.io/py/social-auth-core.svg)](https://badge.fury.io/py/social-auth-core)
[![Donate](https://img.shields.io/badge/Donate-PayPal-orange.svg)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=matiasaguirre%40gmail%2ecom&lc=US&item_name=Python%20Social%20Auth&no_note=0&currency_code=USD&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest)

Python Social Auth is an easy to setup social authentication/registration
mechanism with support for several frameworks and auth providers.

## Description

This is the core component of the python-social-auth ecosystem, it
implements the common interface to define new authentication backends
to third parties services, implement integrations with web frameworks
and storage solutions.

## Documentation

Project documentation is available at http://python-social-auth.readthedocs.org/.

## Setup

```shell
$ pip install social-auth-core
```

## Contributing

See the [CONTRIBUTING.md](CONTRIBUTING.md) document for details.

## Versioning

This project follows [Semantic Versioning 2.0.0](http://semver.org/spec/v2.0.0.html).

## License

This project follows the BSD license. See the [LICENSE](LICENSE) for details.

## Donations

This project is maintened on my spare time, consider donating to keep
it improving.

[![Donate](https://img.shields.io/badge/Donate-PayPal-orange.svg)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=matiasaguirre%40gmail%2ecom&lc=US&item_name=Python%20Social%20Auth&no_note=0&currency_code=USD&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest)
